@@ -7,16 +7,19 @@ HEATER_DID = "C1"
 HEATER_PROTOCOL = "X10"
 HEATER_API = "http://raspberry:8000"
 
-HEATER_USERNAME = "raton"
-HEATER_PASSWORD = "soportep"
+HEATER_USERNAME = "username"
+HEATER_PASSWORD = "password"
 HEATER_MARGIN = 0.0
 HEATER_INCREMENT = 0.5
 
+MINUTES_AFTER_SUNRISE_FOR_DAY = 60
+MINUTES_AFTER_SUNSET_FOR_DAY = 90
+
 #INTERNAL_TEMPERATURE_URI = "http://raspberry/therm/temperature"
 #INTERNAL_TEMPERATURE_URI = "http://localhost:8000/therm/temperature"
 
-LIST_THERMOMETERS_API = "http://raspberry/therm/temperature_api/thermometers?"
-TEMPERATURES_API = "http://raspberry/therm/temperature_api/thermometers"
+LIST_THERMOMETERS_API = "http://raspberry/thermometer/thermometers?"
+#TEMPERATURES_API = "http://raspberry/therm/temperature_api/thermometers"
 #THERMOMETER_API = "http://raspberry/therm/temperature_api/thermometer/"
 
 FLAME_STATS = True
